#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_COSECANT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_COSECANT_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/scalar/cosecant.hpp>

#endif
